@@ -138,7 +138,15 @@ modelLookup <- function(model = NULL)
             ## nnet
             'nnet', 'nnet', 
             ## nodeHarvest
-            'nodeHarvest', 'nodeHarvest', 
+            'nodeHarvest', 'nodeHarvest',
+            ## obliqueRF
+            'ORFridge',
+            ## obliqueRF
+            'ORFpls',
+            ## obliqueRF
+            'ORFsvm',
+            ## obliqueRF
+            'ORFlog',            
             ## obliqueTree
             'obliqueTree', 'obliqueTree', 
             ## OneR
@@ -202,7 +210,9 @@ modelLookup <- function(model = NULL)
             ## rocc
             'rocc', 
             ## rpart
-            'rpart', 
+            'rpart2',
+            ## rpart2
+            'rpart',
             ## rvmLinear
             'rvmLinear', 
             ## rvmPoly
@@ -216,7 +226,9 @@ modelLookup <- function(model = NULL)
             ## sddaLDA
             'sddaLDA', 
             ## sddaQDA
-            'sddaQDA', 
+            'sddaQDA',
+            ## simpls
+            'simpls',            
             ## slda
             'slda', 
             ## smda
@@ -246,7 +258,9 @@ modelLookup <- function(model = NULL)
             ## treebag
             'treebag', 
             ## vbmpRadial
-            'vbmpRadial')
+            'vbmpRadial',
+            ## widekernelpls
+            'widekernelpls')
 
   pNames <- c(## ada
               'iter', 'maxdepth', 'nu',
@@ -385,7 +399,12 @@ modelLookup <- function(model = NULL)
               ## nnet
               'size', 'decay', 
               ## nodeHarvest
-              'maxinter', 'mode', 
+              'maxinter', 'mode',
+              ## obliqueRF
+              'mtry',
+              'mtry',
+              'mtry',
+              'mtry',
               ## obliqueTree
               'oblique.splits', 'variable.selection', 
               ## OneR
@@ -448,8 +467,10 @@ modelLookup <- function(model = NULL)
               'parameter', 
               ## rocc
               'xgenes', 
+              ## rpart2
+              'maxdepth',
               ## rpart
-              'maxdepth', 
+              'cp',
               ## rvmLinear
               'parameter', 
               ## rvmPoly
@@ -463,7 +484,9 @@ modelLookup <- function(model = NULL)
               ## sddaLDA
               'parameter', 
               ## sddaQDA
-              'parameter', 
+              'parameter',
+              ## simpls
+              'ncomp',              
               ## slda
               'parameter', 
               ## smda
@@ -493,7 +516,9 @@ modelLookup <- function(model = NULL)
               ## treebag
               'parameter', 
               ## vbmpRadial
-              'estimateTheta')
+              'estimateTheta',
+              ## widekernelpls
+              'ncomp')
 
 
   pLabel <- c(## ada
@@ -526,7 +551,7 @@ modelLookup <- function(model = NULL)
               ## cforest
               '#Randomly Selected Predictors',
               ## ctree
-              'P-Value Threshold',
+              '1 - P-Value Threshold',
               ## ctree2
               'Max Tree Depth',
               ## Cubist
@@ -665,6 +690,11 @@ modelLookup <- function(model = NULL)
               ## nodeHarvest
               'Maximum Interaction Depth',
               'Prediction Mode',
+              ## obliqueRF
+              '# Randomly Selected Predictors',
+              '# Randomly Selected Predictors',
+              '# Randomly Selected Predictors',
+              '# Randomly Selected Predictors',            
               ## obliqueTree
               'Oblique Splits',
               'Variable Selection Method',
@@ -735,8 +765,10 @@ modelLookup <- function(model = NULL)
               'none',
               ## rocc
               '#Variables Retained',
-              ## rpart
+              ## rpart2
               'Max Tree Depth',
+              ## rpart
+              'Complexity Parameter',
               ## rvmLinear
               'none',
               ## rvmPoly
@@ -753,6 +785,8 @@ modelLookup <- function(model = NULL)
               'none',
               ## sddaQDA
               'none',
+              ## simpls
+              '#Components',              
               ## slda
               'none',
               ## smda
@@ -796,7 +830,10 @@ modelLookup <- function(model = NULL)
               ## treebag
               'none',
               ## vbmpRadial
-              'Theta Estimated')
+              'Theta Estimated',
+              ## widekernelpls
+              '#Components'
+              )
 
   isSeq <- c(## ada
              FALSE, FALSE, FALSE,
@@ -935,7 +972,12 @@ modelLookup <- function(model = NULL)
              ## nnet
              FALSE, FALSE, 
              ## nodeHarvest
-             FALSE, FALSE, 
+             FALSE, FALSE,
+             ## obliqueRF
+             FALSE,
+             FALSE,
+             FALSE,
+             FALSE,
              ## obliqueTree
              FALSE, FALSE, 
              ## OneR
@@ -998,8 +1040,10 @@ modelLookup <- function(model = NULL)
              FALSE, 
              ## rocc
              FALSE, 
+             ## rpart2
+             TRUE,
              ## rpart
-             TRUE, 
+             TRUE,
              ## rvmLinear
              FALSE, 
              ## rvmPoly
@@ -1013,7 +1057,9 @@ modelLookup <- function(model = NULL)
              ## sddaLDA
              FALSE, 
              ## sddaQDA
-             FALSE, 
+             FALSE,
+             ## simpls
+             TRUE,             
              ## slda
              FALSE, 
              ## smda
@@ -1043,7 +1089,10 @@ modelLookup <- function(model = NULL)
              ## treebag
              FALSE, 
              ## vbmpRadial
-             FALSE)
+             FALSE,
+             ## widekernelpls
+             TRUE
+             )
   isRegMod <- c(## ada
                 FALSE, FALSE, FALSE,
                 ## avnnet
@@ -1181,7 +1230,12 @@ modelLookup <- function(model = NULL)
                 ## nnet
                 TRUE, TRUE, 
                 ## nodeHarvest
-                TRUE, TRUE, 
+                TRUE, TRUE,
+                ## obliqueRF
+                FALSE,
+                FALSE,
+                FALSE,
+                FALSE,
                 ## obliqueTree
                 FALSE, FALSE, 
                 ## OneR
@@ -1244,8 +1298,10 @@ modelLookup <- function(model = NULL)
                 TRUE, 
                 ## rocc
                 FALSE, 
+                ## rpart2
+                TRUE,
                 ## rpart
-                TRUE, 
+                TRUE,
                 ## rvmLinear
                 TRUE, 
                 ## rvmPoly
@@ -1259,7 +1315,9 @@ modelLookup <- function(model = NULL)
                 ## sddaLDA
                 FALSE, 
                 ## sddaQDA
-                FALSE, 
+                FALSE,
+                ## simpls
+                TRUE,                
                 ## slda
                 FALSE, 
                 ## smda
@@ -1289,7 +1347,10 @@ modelLookup <- function(model = NULL)
                 ## treebag
                 TRUE, 
                 ## vbmpRadial
-                FALSE)
+                FALSE,
+                ## widekernelpls
+                TRUE
+                )
 
   isClassMod <- c(## ada
                   TRUE, TRUE, TRUE,
@@ -1428,7 +1489,12 @@ modelLookup <- function(model = NULL)
                   ## nnet
                   TRUE, TRUE, 
                   ## nodeHarvest
-                  TRUE, TRUE, 
+                  TRUE, TRUE,
+                  ## obliqueRF
+                  TRUE,
+                  TRUE,
+                  TRUE,
+                  TRUE,
                   ## obliqueTree
                   TRUE, TRUE, 
                   ## OneR
@@ -1491,8 +1557,10 @@ modelLookup <- function(model = NULL)
                   FALSE, 
                   ## rocc
                   TRUE, 
+                  ## rpart2
+                  TRUE,
                   ## rpart
-                  TRUE, 
+                  TRUE,
                   ## rvmLinear
                   FALSE, 
                   ## rvmPoly
@@ -1506,9 +1574,11 @@ modelLookup <- function(model = NULL)
                   ## sddaLDA
                   TRUE, 
                   ## sddaQDA
-                  TRUE, 
+                  TRUE,
+                  ## simpls
+                  FALSE,                   
                   ## slda
-                  TRUE, 
+                  TRUE,                 
                   ## smda
                   TRUE, TRUE, TRUE, 
                   ## sparseLDA
@@ -1536,7 +1606,10 @@ modelLookup <- function(model = NULL)
                   ## treebag
                   TRUE, 
                   ## vbmpRadial
-                  TRUE)
+                  TRUE,
+                  ## widekernelpls
+                  FALSE
+                  )
 
   hasProbModel <- c(## ada
                     TRUE, TRUE, TRUE,
@@ -1675,7 +1748,12 @@ modelLookup <- function(model = NULL)
                     ## nnet
                     TRUE, TRUE, 
                     ## nodeHarvest
-                    TRUE, TRUE, 
+                    TRUE, TRUE,
+                    ## obliqueRF
+                    TRUE,
+                    TRUE,
+                    TRUE,
+                    TRUE,
                     ## obliqueTree
                     TRUE, TRUE, 
                     ## OneR
@@ -1738,8 +1816,10 @@ modelLookup <- function(model = NULL)
                     FALSE, 
                     ## rocc
                     FALSE, 
+                    ## rpart2
+                    TRUE,
                     ## rpart
-                    TRUE, 
+                    TRUE,
                     ## rvmLinear
                     FALSE, 
                     ## rvmPoly
@@ -1753,7 +1833,9 @@ modelLookup <- function(model = NULL)
                     ## sddaLDA
                     TRUE, 
                     ## sddaQDA
-                    TRUE, 
+                    TRUE,
+                    ## simpls
+                    FALSE,
                     ## slda
                     TRUE, 
                     ## smda
@@ -1783,7 +1865,10 @@ modelLookup <- function(model = NULL)
                     ## treebag
                     TRUE, 
                     ## vbmpRadial
-                    TRUE)
+                    TRUE,
+                    ## widekernelpls
+                    FALSE
+                    )
   
   
   paramKey <- data.frame(model = mods,
